close all
clear all

% the possible phases to crystallize or melt are:
% [olivine opx pigeonite augite plagioclase garnet amphibole ilmenite magnetite] 

%% STEP 1: input liquid composition
%%%% I am assuming you want to track the
%%%% evolution of 1 liquid composition (not a bunch).  Use the function to iterate through different liquid compositions.
%%%% As of now, the liquid matrix currently contains 11 columns
%            1       2       3         4      5        6     7      8          9         10         11
%          SiO2	TiO2 Al2O3	Cr2O3  FeO	MnO	MgO	CaO	    Na2O	K2O	  P2O5
%liqComp = [52.06	1.471	17.95	NaN	  8.51   	0.157    6.44	8.89  4.09	0.62	0.281];%original Lk Shannon 114 
%liqComp = [52.56	1.64	17.63	NaN	  8.73   	0.165    5.42	8.39  4.44	0.9	0.43] % original sulphur creek 
%liqComp = [51.4	1.06	19.43	NaN	  6.63   	0.1    7.46	9.39  3.7	0.54	0.26] % sulphur creek 
%liqComp = [47.01	1.07	15.28	NaN	  8.79   	0.16    12.50	10.96  2.23	0.47 NaN] % STV-301 pichavant/health 
%liqComp = [47.6	1.06	15.2	NaN	  8.95   	0.16    13.4	10.9  2.2	0.47 NaN] % STV-301 pichavant/health after 3% oliv crystallization
%liqComp = [48.24   0.47	  9.09	  NaN	  8.21   	0.15    15.36	14.09  1.42	0.52 NaN] % kohut ankaramite
%liqComp = [46.2   0.62	  17.17	  NaN	  10.35   	0.19    5.5	12.03  1.8	0.58 0.13] % kelley agrigan
%liqComp = [45.86   0.78	  17.78	  NaN	  11.98   	0.25    5.53	12.26  1.94	0.32 0.04] % kelley guguan
%liqComp = [49.1   0.62	  14.6	  NaN	  11.12   	0.15    7.21	9.4  2.8	0.59 0.07] % kelley pagan
%liqComp = [51.7   0.9	  15.88	  NaN	  8.46   	0.18    4.91	10.14  2.7	0.50 0] % kelley sarigan
%liqComp = [54.73   0.23	  10.26	  NaN	  8.06   	NaN   16.34  7.25	1.35 0.57 NaN] % Li boninite
%liqComp = [62.57   0.28	  13.17	  NaN	  3.92   	NaN   8.5  4.66	3.75 1.66 NaN] % Li adakite
%liqComp = [50.51   1.41	  17.88	  NaN	  9.36   	0.15   7.18  9.46	2.90 0.55 0.29] % Rowe CC02-1 CAB
liqComp = [46.89   2.05	  17.89	  NaN	  9.51   	0.13   6.13  12.12	3.70 0.72 0.41] % Rowe HL03-1 EIB
%liqComp = [48.75   2.02	  17.14	  NaN	  10.68   	0.18   6.02  10.47	3.46 0.54 0.38] % Rowe NEF03-1 LKT
%liqComp = [51.13   1.16	  15.33	  NaN	  8.14  	0.14   9.86  9.08	3.12 1.68 0.34] % Leeman V123A
%liqComp = [52.15  1.5	  16.67	  NaN	  8.04  	0.13   8.278  8.126	3.56 1.112 0.414] % Leeman V185A
%liqComp = [51.48   1.11	  17.05	  NaN	  7.41  	0.13   8.304  9.49	3.69 1.02 0.30] % Leeman V97-15
%liqComp = [52.0   0.3	 8.4	  NaN	  8.51  	0.10   21.9  7.0	1.0 0.41 0.10] % Sobolev 26-2
%liqComp = [51.4   0.18	 7.6	  NaN	  9.20  	0.2   24.0  6.4	0.8 0.15 0.02] % Sobolev 26-3
%liqComp = [56.5   0.26	 11.36	  NaN	  9.37  	0.29   11.09  9.57	1.19 0.22 0.03] % Sobolev 26-3 w oliv removed
%liqComp = [48.02   0.34	 9.67	  NaN	  9.51  	0.14   18.94  10.27	1.35 0.25 0.24] % Kamenetsky Tumrok less weird
liqComp = 100*liqComp/nansum(liqComp); %%normalizes the liquid composition


%% STEP 2: input final percent crystallization and increment.  Note you could also use a while loop if you have a particular stopping point. 
%%% I used the same manner of calculation as the FORTRAN code where the
%%% percentIncrement variable dictates the percent removed from the
%%% remaining liquid (so if percentIncrement = 1, then after 1 step you
%%% have 99% liquid left, after 2 steps you have 98.01% of the original
%%% liquid left).  The matrix F stores this number.  
percent = 50;
percentIncrement = 1;


%% STEP 3: dictate the phase proportions, not in percent
%%% make sure they sum to 1 and have the right sign.  the default is to fractionate (or subtract) phases.  a negative sign means it will add minerals back. 
%%%                      [olivine opx  pigeonite augite plagioclase garnet amphibole ilmenite magnetite] 
%phaseProportions = [.2       0.3         0         0        .5             0        0            0              0];
phaseProportions = [-1      0         0         0       0           0        0            0           0];
disp(['The sum of the phases is: ' num2str(sum(phaseProportions))])
    

%% STEP 4: check Kds
% For now we are using these set Kds. Change them to your liking.  
% In the future we could have a parameterized value that calculates within 
% the routine based on the liquid comp (or T and P). 
%%% The KDs are all FeMg, except for plag (CaNa) and the additional SiMg
%%% for garnet.  You may want to specifcy more KDs, and I'm happy to
%%% include those.
%%%     oliv   opx  pig/augite  plag  amphibole garnet[FeMg  SiMg]   
%%%      1      2           3         4          5                   6       7       
KDs = [0.30  0.24      0.24      1.7       0.35             0.48   0.8];

%% STEP 5: define any composition-invariant phases
%            1       2       3         4      5        6     7      8          9         10         11
%          SiO2	TiO2 Al2O3	Cr2O3  FeO	MnO	MgO	CaO	    Na2O	K2O	    P2O5
%%magnetite and ilmenite comps are already defined.  You can set to known comp for any
%%mineal that is not included above
magnetiteComp = [0   7.8  2.7 0   87.9  0   1.6  0   0  0   0]; %%This is the default in the fortran code, change this for your comp!
ilmeniteComp = [0 45 0.5 0 50 0.5 4 0 0 0 0]; %%This is some real comp from Ben's expts, change!
%%% pure ilmenite FeTiO3 = [0 52.65 0 0 47.35 0 0 0 0 0 0];

%%% end of things to change 


%% Now calculate crystallization:

%%% the liquid composition matrix initially saves the original liq comp in
%%% the first row, edit line 60 (**) to change this
liquidCompPost = zeros(percent+1,11);
liquidCompPost(1,:) = liqComp; %% (**): change here if you don't want to save the initial liq in the derivative liquid comp matrix
n =1; % i and n will be different if the percentIncrmenet is not = 1
Increment = percentIncrement/100;
F(1) = 1;



for i = 1:percentIncrement:percent
    
    %%% for each increment of fractional crystallization, a routine is called
    %%% to calculate the equlibrium mineral composition (and save it in a
    %%% matrix) based on the transient liquid composition and the Kd matrix.  
    %%% If you want to control the mineral composition more,
    %%% change the Kd matrix or the mineral routine. 
    %%% The only reason why I dictate the Kd here is so that it's easy
    %%% to change the Kd and test sensitivity from the main routine. 

    olivine(n,:) = fractionateOlivine(liquidCompPost(n,:),KDs(1));
    opx(n,:) = fractionateOpx(liquidCompPost(n,:),KDs(2));
    pigeonite(n,:) = fractionatePIG(liquidCompPost(n,:),KDs(3));
    augite(n,:) = fractionateAugite(liquidCompPost(n,:),KDs(3));
    plagioclase(n,:) = fractionatePlagioclase(liquidCompPost(n,:),KDs(4));
    amphibole(n,:) = fractionateAmphibole(liquidCompPost(n,:),KDs(5));
    garnet(n,:) = fractionateGarnet(liquidCompPost(n,:),KDs(6),KDs(7));
    
    %%% uses input compositions, can change later to make it liquid
    %%% comp, T,P, fO2 dependent if useful
    ilmenite(n,:) = ilmeniteComp;
    magnetite(n,:) = magnetiteComp;
    
    %%% now combine the mineral data into a matrix 
    %%% each row is a mineral composition.  If you add minerals,
    %%% make sure to change it here.
    %%% [olivine opx  pigeonite augite plagioclase garnet amphibole ilmenite magnetite] 
    clearvars temp
    temp = [olivine(n,:); opx(n,:); pigeonite(n,:); augite(n,:); plagioclase(n,:); garnet(n,:); amphibole(n,:); ilmenite(n,:); magnetite(n,:)];
    solidphases(n,:) = phaseProportions*temp; %%multiples each mineral times its proportion, saves it in a new matrix
    
    %%% the new liquid compostiion is calculated by removing an increment of
    %%% solid material. 
        liquidCompPost(n+1,:) = liquidCompPost(n,:) - (Increment*(solidphases(n,:))); 
        liquidCompPost(n+1,:) = 100*liquidCompPost(n+1,:)./nansum(liquidCompPost(n+1,:)); %%normalizes the liquid composition
        %liquidCompPost(n+1,12) = (liquidCompPost(n+1,7)/40.311)./((liquidCompPost(n+1,5)/40.311)+(liquidCompPost(n+1,7)/71.846)); %% added 7/18/14, calculates Mg#.
        F(n+1) = (1-Increment)^n;
        
        n=n+1;
end

%%% converts solid phases to positive values to offset more addition than
%%% fractionation
solidphases = abs(solidphases);

%%% tacks on a new column with Mg# for each compositional matrix.  Could
%%% make this also calc NaK#s, etc...
liqComp= addMgNum(liqComp);
liquidCompPost= addMgNum(liquidCompPost);
solidphases= addMgNum(solidphases);
olivine= addMgNum(olivine);
opx= addMgNum(opx);
pigeonite= addMgNum(pigeonite);
augite= addMgNum(augite);
plagioclase= addMgNum(plagioclase);
amphibole= addMgNum(amphibole);
garnet= addMgNum(garnet);
ilmenite= addMgNum(ilmenite);
magnetite= addMgNum(magnetite);


display('The total liquid remaining after each iteration in % is:')
disp(F*100)


 %% figures
 %%%  STEPS:  
 %%% 1. Comment/uncomment phases you have/don't have, or want/don't want to graph.  
 %%% 2. Change j to the indicies of the elements you want along the Y-axis, and change "xvalue" to the index of the element you want to plot along X.
 %%% 3. Fix the legend to reflect step 1.
 %%% The code will automatically change the axis labels and figure title.  
 %%% I have TONS of other scripts that do things like this, so let me know if you want something more complex.
 %            1       2       3         4          5       6      7      8          9         10         11
%          SiO2	TiO2 Al2O3	Cr2O3  FeO	MnO	MgO	CaO	    Na2O	K2O	    P2O5
 for j = [1 2 3 5 7 8 9] %%[SiO2 TiO2 Al2O3 FeO MgO CaO Na2O] change this how you want, but j contains the indicies for the oxides you want to plot along the y (can change to x, etc...)
figure()
hold on


%%xvalue and yvalue are the only things to change
%xvalue = 7; %MgO
xvalue = 12; %Mg#
yvalue = j; 

%%comment out anything you don't want to plot.
plot(liquidCompPost(:,xvalue),liquidCompPost(:,yvalue),'o-k','MarkerFaceColor','y')
plot(liqComp(:,xvalue),liqComp(:,yvalue),'*r')
plot(olivine(:,xvalue),olivine(:,yvalue),'og','MarkerFaceColor','g')
%plot(opx(:,xvalue),opx(:,yvalue),'ok','MarkerFaceColor','b')
%plot(plagioclase(:,xvalue),plagioclase(:,yvalue),'or','MarkerFaceColor','r')
plot(solidphases(:,xvalue),solidphases(:,yvalue),'ok','MarkerFaceColor','k')

%%% Uncomment to plot the comp of other crystlalizing phases but change the
%%% marker color and add to the legend!!

% plot(pigeonite(:,xvalue),pigeonite(:,yvalue),'or','MarkerFaceColor','r')
% plot(augite(:,xvalue),augite(:,yvalue),'or','MarkerFaceColor','r')
% plot(garnet(:,xvalue),garnet(:,yvalue),'or','MarkerFaceColor','r')
% plot(amphibole(:,xvalue),amphibole(:,yvalue),'or','MarkerFaceColor','r')
% plot(ilmenite(:,xvalue),ilmenite(:,yvalue),'or','MarkerFaceColor','r')
% plot(magnetite(:,xvalue),magnetite(:,yvalue),'or','MarkerFaceColor','r')
legend('residual liquid composition', 'original liquid comp','olivine comp','opx comp','plagioclase comp','total solid composition')

%labels
[Xtext,Ytext,FigureTitle] = oxideLabel(xvalue,yvalue);
xlabel(Xtext)
ylabel(Ytext)
title(FigureTitle)
end




