close all
clear all

% the possible phases to crystallize or melt are:
% [olivine opx pigeonite augite plagioclase garnet amphibole ilmenite magnetite] 

%% STEP 1: input liquid composition
%%%%I am assuming you want to track the
%%%%evolution of 1 liquid composition (not a bunch).  As of now, the liquid
%%%%matrix currently contains 11 columns

%            1       2       3         4          5       6      7      8          9         10         11
%          SiO2	TiO2 Al2O3	Cr2O3  FeO	MnO	MgO	CaO	    Na2O	K2O	    P2O5
liqComp = [48.9	1.96	10.8	NaN	  11.2	0	15	8.91	1.71	0.31	0.18];
liqComp = 100*liqComp/nansum(liqComp); %%normalizes the liquid composition

%% STEP 2: input assimilant composition
% % % % % %            1       2       3         4         5      6       7       8       9      10    11
% % % % % %          SiO2  TiO2  Al2O3	Cr2O3  FeO	MnO	 MgO  CaO  Na2O	K2O	P2O5
assimilant_liqComp = [45.9	1.96	10.8	   0	   11.2	   0	 15	     8.91	1.71   0.31	0.18]; 
assimilant_liqComp = 100*assimilant_liqComp/nansum(assimilant_liqComp); %%normalizes the assimilated liquid composition

%% STEP 3: input percent crystallization and increment.  You could also use a while loop if you have a particular stopping point.  
%%% I used the same manner of calculation as the FORTRAN code where the
%%% percentIncrement variable dictates the percent removed from the
%%% remaining liquid (so if percentIncrement = 1, then after 1 step you
%%% have 99% liquid left, after 2 steps you have 98.01% of the original
%%% liquid left).  The matrix F stores this number.  
percent = 10; %% in percent!
percentIncrement = 1; %% in percent!
percentAssimilant = 0.25; %% in percent!  CHANGE TO 0 IF YOU DON'T WANT TO ASSIMILATE


%% STEP 4: dictate the phase proportions (ignore assimilant proportion)
%%% make sure they sum to 1 and have the right sign.  the default is to fractionate (or subtract) phases.  a negative sign means it will add minerals back. 
%%%                      [olivine opx  pigeonite augite plagioclase garnet amphibole ilmenite magnetite] 
phaseProportions = [.2       0.3         0         0        .5             0        0            0              0];
disp(['The sum of the phases is: ' num2str(sum(phaseProportions))])


%% STEP 5: check Kds
% For now we are using these set Kds. Change them to your liking.  
% In the future we could have a parameterized value that calculates within 
% the routine based on the liquid comp (or T and P). 
%%% The KDs are all FeMg, except for plag (CaNa) and the additional SiMg
%%% for garnet.  You may want to specifcy more KDs, and I'm happy to
%%% include those.
%%%     oliv   opx  pig/augite  plag  amphibole garnet[FeMg  SiMg]   
%%%       1      2           3         4          5                   6       7       
KDs = [0.29  0.27      0.23      6.0       0.35             0.48   0.8];

%% STEP 6: define any composition-invariant phases
%            1       2       3         4      5        6     7      8          9         10         11
%          SiO2	TiO2 Al2O3	Cr2O3  FeO	MnO	MgO	CaO	    Na2O	K2O	    P2O5
%%magnetite and ilmenite comps are already defined.  You can set to known comp for any
%%mineal that is not included above
magnetiteComp = [0   7.8  2.7 0   87.9  0   1.6  0   0  0   0]; %%This is the default in the fortran code, change this for your comp!
ilmeniteComp = [0 45 0.5 0 50 0.5 4 0 0 0 0]; %%This is some real comp from Ben's expts, change!
%%% pure ilmenite FeTiO3 = [0 52.65 0 0 47.35 0 0 0 0 0 0];

%%% end of things to change 

%% Now calculate crystallization:

%%% the liquid composition matrix initially saves the original liq comp in
%%% the first row, edit line 60 (**) to change this
liquidCompPost = zeros(percent+1,11);
liquidCompPost(1,:) = liqComp; %% (**): change here if you don't want to save the initial liq in the derivative liquid comp matrix
n = 1; % i and n will be differnet if the percentIncrmenet is not = 1
Increment = percentIncrement/100;
AssimilantIncrement = percentAssimilant/100;
disp(['The percent assimilant is set to: ' num2str(AssimilantIncrement*100) '%'])
F(1) = 1;

for i = 1:percentIncrement:percent
    
    %%% for each increment of fractional crystallization, a routine is called
    %%% to calculate the equlibrium mineral composition (and save it in a
    %%% matrix) based on the transient liquid composition and the Kd matrix.  
    %%% If you want to control the mineral composition more,
    %%% change the Kd matrix or the mineral routine. 
    %%% The only reason why I dictate the Kd here is so that it's easy
    %%% to change the Kd and test sensitivity from the main routine. 
 
    olivine(n,:) = fractionateOlivine(liquidCompPost(n,:),KDs(1));
    opx(n,:) = fractionateOpx(liquidCompPost(n,:),KDs(2));
    pigeonite(n,:) = fractionatePIG(liquidCompPost(n,:),KDs(3));
    augite(n,:) = fractionateAugite(liquidCompPost(n,:),KDs(3));
    plagioclase(n,:) = fractionatePlagioclase(liquidCompPost(n,:),KDs(4));
    amphibole(n,:) = fractionateAmphibole(liquidCompPost(n,:),KDs(5));
    garnet(n,:) = fractionateGarnet(liquidCompPost(n,:),KDs(6),KDs(7));
    
    %%% uses input compositions, can change later to make it liquid
    %%% comp, T,P, fO2 dependent if useful
    ilmenite(n,:) = ilmeniteComp;
    magnetite(n,:) = magnetiteComp;
    
    %%% now combine the mineral data into a matrix 
    %%% each row is a mineral composition.  If you add minerals,
    %%% make sure to change it here.
    %%% [olivine opx  pigeonite augite plagioclase garnet amphibole ilmenite magnetite] 
    
    clearvars temp 
    temp = [olivine(n,:); opx(n,:); pigeonite(n,:); augite(n,:); plagioclase(n,:); garnet(n,:); amphibole(n,:); ilmenite(n,:); magnetite(n,:)];
    solidphases(n,:) = phaseProportions*temp; %%multiples each mineral times its proportion, saves it in a new matrix
    
    %%% the new liquid compostiion is calculated by removing increment of
    %%% solid material. 

        liquidCompPost(n+1,:) = liquidCompPost(n,:) - (Increment*(solidphases(n,:))) + AssimilantIncrement*(assimilant_liqComp); 
        liquidCompPost(n+1,:) = 100*liquidCompPost(n+1,:)./nansum(liquidCompPost(n+1,:)); %%normalizes the liquid composition
        F(n+1) = (1-Increment)^n; %There might be a better expression including the assimlant
        
    n=n+1;
end

%%% converts solid phases to positive values to offset more addition than
%%% fractionation
solidphases = abs(solidphases);

%%% tacks on a new column with Mg# for each compositional matrix.  Could
%%% make this also calc NaK#s, etc...
liqComp= addMgNum(liqComp);
liquidCompPost= addMgNum(liquidCompPost);
solidphases= addMgNum(solidphases);
assimilant_liqComp= addMgNum(assimilant_liqComp);
olivine= addMgNum(olivine);
opx= addMgNum(opx);
pigeonite= addMgNum(pigeonite);
augite= addMgNum(augite);
plagioclase= addMgNum(plagioclase);
amphibole= addMgNum(amphibole);
garnet= addMgNum(garnet);
ilmenite= addMgNum(ilmenite);
magnetite= addMgNum(magnetite);


display('The total liquid remaining after each iteration in % is :')
disp(F*100)

 %% figures
 %%%  STEPS:  
 %%% 1. Comment/uncomment phases you have/don't have, or want/don't want to graph.  
 %%% 2. Change j to the indicies of the elements you want along the Y-axis, and change "xvalue" to the index of the element you want to plot along X.
 %%% 3. Fix the legend to reflect step 1.
 %%% The code will automatically change the axis labels and figure title.  
 %%% I have TONS of other scripts that do things like this, so let me know if you want something more complex.
 %            1       2       3         4          5       6      7      8          9         10         11
%          SiO2	TiO2 Al2O3	Cr2O3  FeO	MnO	MgO	CaO	    Na2O	K2O	    P2O5
 for j = [1 2 3 5 7 8 9] %%[SiO2 TiO2 Al2O3 FeO MgO CaO Na2O] change this how you want, but j contains the indicies for the oxides you want to plot along the y (can change to x, etc...)
figure()
hold on

%            1       2       3         4      5        6     7      8          9         10         11
%          SiO2	TiO2 Al2O3	Cr2O3  FeO	MnO	MgO	CaO	    Na2O	K2O	    P2O5

%%xvalue and yvalue are the only things to change
%xvalue = 7; %MgO
xvalue = 12; %Mg#
yvalue = j; 

%%comment out anything you don't want to plot.
plot(liquidCompPost(:,xvalue),liquidCompPost(:,yvalue),'o-k','MarkerFaceColor','y')
plot(liqComp(:,xvalue),liqComp(:,yvalue),'*r')
plot(assimilant_liqComp(:,xvalue),assimilant_liqComp(:,yvalue),'pr')
plot(olivine(:,xvalue),olivine(:,yvalue),'og','MarkerFaceColor','g')
plot(opx(:,xvalue),opx(:,yvalue),'ok','MarkerFaceColor','b')
plot(plagioclase(:,xvalue),plagioclase(:,yvalue),'or','MarkerFaceColor','r')
plot(solidphases(:,xvalue),solidphases(:,yvalue),'ok','MarkerFaceColor','k')

%%% Uncomment to plot the comp of other crystlalizing phases but change the
%%% marker color and add to the legend!!

% plot(pigeonite(:,xvalue),pigeonite(:,yvalue),'or','MarkerFaceColor','r')
% plot(augite(:,xvalue),augite(:,yvalue),'or','MarkerFaceColor','r')
% plot(garnet(:,xvalue),garnet(:,yvalue),'or','MarkerFaceColor','r')
% plot(amphibole(:,xvalue),amphibole(:,yvalue),'or','MarkerFaceColor','r')
% plot(ilmenite(:,xvalue),ilmenite(:,yvalue),'or','MarkerFaceColor','r')
% plot(magnetite(:,xvalue),magnetite(:,yvalue),'or','MarkerFaceColor','r')
legend('residual liquid composition', 'original liquid comp','assimilant liquid comp','olivine comp','opx comp','plagioclase comp','total solid composition')

%labels
[Xtext,Ytext,FigureTitle] = oxideLabel(xvalue,yvalue);
xlabel(Xtext)
ylabel(Ytext)
title(FigureTitle)
end




